@@ -9,13 +9,11 @@ from .exceptions import (
 
 from .models import Novel, Volume, Chapter, Metadata
 
-from .sources import (
-    Source, MetaSource,
-    sources, meta_sources
+from .sources import Source, MetaSource
+
+from .utils.sources import (
+    novel_source_types, locate_novel_source,
+    metadata_source_types, locate_metadata_source,
 )
 
-from .utils import (
-    parse_source, parse_metasource,
-    novel_source_types, metadata_source_types,
-    locate_novel_source, locate_metadata_source,
-)
+from .utils.http import BaseHttpGateway
