@@ -1,4 +1,4 @@
-from typing import List, Tuple
+import datetime
 
 from .source import Source
 from ...models import Chapter, Novel, Metadata
@@ -6,10 +6,10 @@ from ...models import Chapter, Novel, Metadata
 
 class NovelPassion(Source):
     base_urls = ('https://www.novelpassion.com',)
+    last_updated = datetime.date(2021, 9, 4)
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
-        metadata = []
 
         authors = [a.text.strip() for a in soup.select('.dns .stq[href*="author"]')]
         synopsis_paragraphs = [p.text.strip() for p in soup.select('.j_synopsis p')]
@@ -18,14 +18,14 @@ class NovelPassion(Source):
             title=soup.select_one('.psn h2.ddm').text.strip(),
             author=', '.join(authors),
             thumbnail_url=self.base_urls[0] + soup.select_one('.g_thumb img')['src'],
-            synopsis='\n'.join(synopsis_paragraphs),
+            synopsis=synopsis_paragraphs,
             url=url,
         )
 
         for a in soup.select('.dns .stq[href*="category"]'):
-            metadata.append(Metadata('subject', a.text.strip()))
+            novel.metadata.append(Metadata('subject', a.text.strip()))
 
-        chapters = []
+        volume = novel.get_default_volume()
         for i, a in enumerate(reversed(soup.select('.content-list a'))):
             chapter = Chapter(
                 index=i,
@@ -33,9 +33,9 @@ class NovelPassion(Source):
                 url=self.base_urls[0] + a['href'],
             )
 
-            chapters.append(chapter)
+            volume.chapters.append(chapter)
 
-        return novel, chapters, metadata
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
