@@ -1,5 +1,5 @@
 import datetime
-from typing import Tuple, List
+from typing import List
 
 from .source import Source
 from ...models import Novel, Chapter, Metadata
@@ -8,11 +8,10 @@ from ...models import Novel, Chapter, Metadata
 class RainOfSnow(Source):
     name = 'Rain Of Snow Translations'
     base_urls = ('https://rainofsnow.com/',)
-    last_updated = datetime.date(2021, 8, 16)
+    last_updated = datetime.date(2021, 9, 4)
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
-        metadata = []
 
         novel = Novel(
             title=soup.select_one('.text h2').text.strip(),
@@ -25,31 +24,39 @@ class RainOfSnow(Source):
             key, value = li.select_one('.vt1').text.strip(), li.select_one('.vt2').text.strip()
             if key.lower() == 'author':
                 novel.author = value
+
             elif key.lower() == 'translator':
-                metadata.append(Metadata('author', value, others={'role': 'translator'}))
+                novel.metadata.append(Metadata('contributor', value, others={'role': 'translator'}))
+
             elif key.lower() == 'editor':
-                metadata.append(Metadata('author', value, others={'role': 'editor'}))
+                novel.metadata.append(Metadata('contributor', value, others={'role': 'editor'}))
+
             elif key.lower() == 'genre(s)':
                 for word in value.split(','):
-                    metadata.append(Metadata('subject', word.strip()))
+                    if not word.strip():
+                        continue
+                    novel.metadata.append(Metadata('subject', word.strip()))
+
             elif key.lower() == 'type':
-                metadata.append(Metadata('type', value))
+                novel.metadata.append(Metadata('type', value))
 
-        # tags selector: .vbtcolor1 > li a[href*="tag"]
+        for tag in soup.select('.vbtcolor1 > li a[href*="tag"]'):
+            novel.metadata.append(Metadata('tag', tag.strip()))
 
-        chapters = []
+        volume = novel.get_default_volume()
         for a in soup.select('#chapter .chapter a'):
             chapter = Chapter(
-                index=len(chapters),
+                index=len(volume.chapters),
                 title=a.text.strip(),
                 url=a['href'],
             )
 
-            chapters.append(chapter)
+            volume.chapters.append(chapter)
 
-        return novel, chapters, metadata
+        return novel
 
-    def synopsis(self, soup) -> str:
+    @staticmethod
+    def synopsis(soup) -> List[str]:
         paragraphs = []
         for element in soup.select('#synop > p'):
             if not element.text.strip():
@@ -57,7 +64,7 @@ class RainOfSnow(Source):
 
             paragraphs.append(element.text)
 
-        return '\n'.join(paragraphs)
+        return paragraphs
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
