@@ -1,4 +1,4 @@
-from typing import List, Tuple
+import datetime
 
 from .source import Source
 from ...models import Chapter, Novel, Metadata
@@ -7,6 +7,7 @@ from ...models import Chapter, Novel, Metadata
 class WuxiaCom(Source):
     name = 'WuxiaWorld.com'
     base_urls = ('https://www.wuxiaworld.com',)
+    last_updated = datetime.date(2021, 9, 4)
 
     blacklist_patterns = [
         r'^<span>(...|\u2026)</span>$',
@@ -14,32 +15,42 @@ class WuxiaCom(Source):
         r'(volume|chapter) .?\d+',
     ]
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
 
-        authors = ''
-        for d in soup.select_one('.media-body dl, .novel-body').select('dt, dd'):
-            authors += d.text.strip()
-            authors += ' ' if d.name == 'dt' else '; '
-
         novel = Novel(
             title=soup.select_one('.section-content h2').text,
+            synopsis=[p.text.strip() for p in soup.select('.fr-view:not(.pt-10) p')],
             thumbnail_url=soup.select_one('img.media-object').get('src'),
-            author=authors.strip().strip(';'),
             url=url,
         )
 
-        chapters = []
+        author_elements = soup.select('.novel-body :is(dt, dd)')
+        for i, element in enumerate(author_elements):
+            if element.name != 'dt':
+                continue
+
+            head = element.text.strip()
+            if head == 'Translator:':
+                novel.metadata.append(Metadata('contributor', author_elements[i + 1].text.strip()))
+            elif head == 'Author:':
+                novel.author = author_elements[i + 1].text.strip()
+
+        for a in soup.select('.genres a'):
+            novel.metadata.append(Metadata('subject', a.text.strip()))
+
+        volume = novel.get_default_volume()
         for panel in soup.select('#accordion .panel-default'):
             for a in panel.select('ul.list-chapters li.chapter-item a'):
                 chapter = Chapter(
-                    index=len(chapters),
+                    index=len(volume.chapters),
+                    title=a.text.strip(),
                     url=self.base_urls[0] + a['href'],
                 )
 
-                chapters.append(chapter)
+                volume.chapters.append(chapter)
 
-        return novel, chapters, []
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
